@@ -24,6 +24,21 @@ arma::uvec sample_indices(const arma::uword size, arma::vec &probs);
 arma::uvec systematic_resampling(arma::vec &probs);
 arma::uvec systematic_resampling(const arma::uword size, arma::vec &probs);
 
+/*
+  Wrapper function to use the above and return a tuple with an index and number
+  of replicas
+*/
+template <arma::uvec (*sample_func)(const arma::uword, arma::vec&)>
+std::map<arma::uword, arma::uword>
+  sample_n_count_replicas(const arma::uword size, arma::vec &probs){
+    arma::uvec sample = sample_func(size, probs);
+    std::map<arma::uword, arma::uword> out;
+    for(auto i = sample.begin(); i != sample.end(); ++i)
+      ++out[*i];
+
+    return out;
+  }
+
 /*
   n draws from N(mu, Sigma). See
     http://gallery.rcpp.org/articles/simulate-multivariate-normal/
@@ -34,4 +49,10 @@ arma::mat mvrnorm(const int, const arma::vec&, const arma::mat&);
 arma::vec mvrnorm(const arma::vec&, const arma::mat&);
 arma::vec mvrnorm(const arma::mat&);
 
+arma::mat mvtrnorm(const int, const arma::mat&, const int);
+arma::mat mvtrnorm(const int, const arma::vec&, const arma::mat&,
+                   const int);
+arma::vec mvtrnorm(const arma::vec&, const arma::mat&, const int);
+arma::vec mvtrnorm(const arma::mat&, const int);
+
 #endif
